@@ -3,6 +3,11 @@
 
   # Plot descriptive lines and learner names
   cd$data$yend = -cd$data$yend
+  if (!is.null(cd$data$baseline)) {
+    cd$data$baseline = as.logical(cd$data$baseline)
+  } else {
+    cd$data$baseline = FALSE
+  }
   p = ggplot(cd$data)
 
   # visible binding hack
@@ -14,7 +19,7 @@
                    xend = mean(cd$data$mean_rank) + 0.5 * cd$cd,
                    y = 1.5,
                    yend = 1.5,
-                   size = 1)
+                   linewidth = 1)
 
   # Add crit difference test (descriptive)
   p = p + annotate("text",
@@ -29,11 +34,13 @@
                  aes(x = x, xend = x, y = 0, yend = 0.3))
 
   # Horizontal descriptive bar
-  p = p + geom_segment(aes_string("mean_rank", 0, xend = "mean_rank", yend = "yend"))
+  p = p + geom_segment(aes(!!sym("mean_rank"), 0, xend = !!sym("mean_rank"),
+    yend = !!sym("yend"), lty = "baseline"))
   # Vertical descriptive bar
-  p = p + geom_segment(aes_string("mean_rank", "yend", xend = "xend", yend = "yend"))
+  p = p + geom_segment(aes(!!sym("mean_rank"), !!sym("yend"), xend = !!sym("xend"),
+    yend = !!sym("yend"), lty = "baseline"))
   # Plot Learner name
-  p = p + geom_text(aes_string("xend", "yend", label = obj$col_roles$learner_id,
+  p = p + geom_text(aes(!!sym("xend"), !!sym("yend"), label = !!sym(obj$col_roles$learner_id),
                                hjust = "right"), vjust = -0.5)
 
   p = p + xlab("Average Rank")
@@ -50,21 +57,22 @@
 
   # Plot the critical difference bars
   if (cd$test == "bd") {
-    cdx = as.numeric(unlist(subset(cd$data, baseline == 1, "mean_rank")))
+    cdx = as.numeric(unlist(subset(cd$data, baseline == TRUE, "mean_rank")))
     # Add horizontal bar around baseline
-    p = p + annotate("segment", x = cdx + cd$cd,
+    p = p + annotate("segment", x = c(cdx - cd$cd, cdx + cd$cd),
                      xend = cdx, y = -1, yend = -1,
-                     color = "black", size = 1.3)
+                     color = "black", linewidth = 1.3)
     # Add interval limiting bar's
-    p = p + annotate("segment", x = cdx + cd$cd, xend = cdx + cd$cd, y = -0.7,
-                     yend = -1.3, color = "black", size = 1.3)
+    p = p + annotate("segment", x = c(cdx - cd$cd, cdx + cd$cd),
+                      xend = c(cdx - cd$cd, cdx + cd$cd), y = -0.7,
+                      yend = -1.3, color = "black", linewidth = 1.3)
   } else {
     nemenyi_data = cd$nemenyi_data # nolint
     if (!(nrow(nemenyi_data) == 0L)) {
       # Add connecting bars
       nemenyi_data$y = -nemenyi_data$y
-      p = p + geom_segment(aes_string("xstart", "y", xend = "xend", yend = "y"),
-                           data = nemenyi_data, size = 1.3)
+      p = p + geom_segment(aes(!!sym("xstart"), !!sym("y"), xend = !!sym("xend"), yend = !!sym("y")),
+                           data = nemenyi_data, linewidth = 1.3)
     } else {
       message("No connecting bars to plot!")
     }
@@ -77,19 +85,25 @@
 
 .plot_critdiff_2 = function(obj, meas, p.value, minimize, test, baseline, friedman_global) { # nolint
   cd = obj$.__enclos_env__$private$.crit_differences(meas, minimize, p.value, baseline, test, friedman_global)
-
+  if (!is.null(cd$data$baseline)) {
+    cd$data$baseline = as.logical(cd$data$baseline)
+  } else {
+    cd$data$baseline = FALSE
+  }
   # Plot descriptive lines and learner names
   p = ggplot(cd$data)
   # Point at mean rank
-  p = p + geom_point(aes_string("mean_rank", 0, colour = obj$col_roles$learner_id), size = 3)
+  p = p + geom_point(aes(!!sym("mean_rank"), 0, colour = !!sym(obj$col_roles$learner_id)), size = 3)
   # Horizontal descriptive bar
-  p = p + geom_segment(aes_string("mean_rank", 0, xend = "mean_rank", yend = "yend",
-                                  color = obj$col_roles$learner_id), size = 1)
+  p = p + geom_segment(aes(!!sym("mean_rank"), 0, xend = !!sym("mean_rank"), yend = !!sym("yend"),
+                                  color = !!sym(obj$col_roles$learner_id),
+                                  lty = "baseline"), linewidth = 1)
   # Vertical descriptive bar
-  p = p + geom_segment(aes_string("mean_rank", "yend", xend = "xend",
-                                  yend = "yend", color = obj$col_roles$learner_id), size = 1)
+  p = p + geom_segment(aes(!!sym("mean_rank"), !!sym("yend"), xend = !!sym("xend"),
+                                  yend = !!sym("yend"), color = !!sym(obj$col_roles$learner_id),
+                                  lty = "baseline"), linewidth = 1)
   # Plot Learner name
-  p = p + geom_text(aes_string("xend", "yend", label = obj$col_roles$learner_id,
+  p = p + geom_text(aes(!!sym("xend"), !!sym("yend"), label = !!sym(obj$col_roles$learner_id),
                                color = obj$col_roles$learner_id,
                                hjust = "right"), vjust = -1)
 
@@ -102,7 +116,7 @@
                 legend.position = "none",
                 panel.background = element_blank(),
                 panel.border = element_blank(),
-                axis.line = element_line(size = 1),
+                axis.line = element_line(linewidth = 1),
                 axis.line.y = element_blank(),
                 panel.grid.major = element_blank(),
                 plot.background = element_blank())
@@ -117,26 +131,28 @@
                    xend = mean(cd$data$mean_rank) + 0.5 * cd$cd,
                    y = max(cd$data$yend) + 0.7,
                    yend = max(cd$data$yend) + 0.7,
-                   size = 1.3, alpha = 0.9)
+                   linewidth = 1.3, alpha = 0.9)
 
   # Plot the critical difference bars
+
   if (test == "bd") {
-    cdx = as.numeric(unlist(subset(cd$data, baseline == 1, "mean_rank"))) # nolint
+    cdx = as.numeric(unlist(subset(cd$data, baseline == TRUE, "mean_rank"))) # nolint
     # Add horizontal bar around baseline
-    p = p + annotate("segment", x = cdx + cd$cd,
+    p = p + annotate("segment", x = c(cdx - cd$cd, cdx + cd$cd),
                      xend = cdx, y = 0.5, yend = 0.5,
-                     alpha = 0.9, color = "dimgrey", size = 1.3)
+                     alpha = 0.9, color = "dimgrey", linewidth = 1.3)
     # Add interval limiting bar's
-    p = p + annotate("segment", x = cdx + cd$cd, xend = cdx + cd$cd, y = 0.3,
-                     yend = 0.8, color = "dimgrey", size = 1.3, alpha = 0.9)
+    p = p + annotate("segment", x = c(cdx - cd$cd, cdx + cd$cd),
+                      xend = c(cdx - cd$cd, cdx + cd$cd), y = 0.3,
+                      yend = 0.8, color = "dimgrey", linewidth = 1.3, alpha = 0.9)
     # Add point at learner
     p = p + annotate("point", x = cdx, y = 0.5, alpha = 0.6, color = "black")
   } else {
     nemenyi_data = cd$nemenyi_data # nolint
     if (!(nrow(nemenyi_data) == 0L)) {
       # Add connecting bars
-      p = p + geom_segment(aes_string("xstart", "y", xend = "xend", yend = "y"),
-                           data = nemenyi_data, size = 1.3, color = "dimgrey", alpha = 0.9,
+      p = p + geom_segment(aes(!!sym("xstart"), !!sym("y"), xend = !!sym("xend"), yend = !!sym("y")),
+                           data = nemenyi_data, linewidth = 1.3, color = "dimgrey", alpha = 0.9,
                            )
     } else {
       message("No connecting bars to plot!")
